@@ -550,7 +550,7 @@ class Plan(HeadersMixin):
                 req_data["patches"].update(patch)
             ret = post_request(f"{self.url}/builds", self.headers, req_data)
             # Updating builds_to_submit will update values in builds
-            for (build, data) in zip(builds_to_submit, ret["builds"]):
+            for (build, data) in zip(builds_to_submit, ret):
                 build.build_data = data["download_url"]
                 build.uid = data["uid"]
                 build.status = data
