@@ -318,6 +318,22 @@ def common_options(required):
                 kw["required"] = True
         return click.option(*args, **kw)
 
+    toolchains = [
+        "gcc-8",
+        "gcc-9",
+        "gcc-10",
+        "gcc-11",
+        "clang-10",
+        "clang-11",
+        "clang-12",
+        "clang-nightly",
+        "clang-android",
+        "rust",
+        "rustgcc",
+        "rustclang",
+        "rustllvm",
+    ]
+
     options = [
         option("--git-repo", help="Git repository"),
         option("--git-ref", help="Git reference"),
@@ -343,7 +359,7 @@ def common_options(required):
         ),
         option(
             "--toolchain",
-            help="Toolchain [gcc-8|gcc-9|gcc-10|gcc-11|clang-10|clang-11|clang-12|clang-nightly|clang-android]",
+            help=f"Toolchain [{'|'.join(toolchains)}]",
         ),
         option(
             "--build-name",
@@ -751,6 +767,18 @@ def test(device, kernel, modules, tests, boot_args, wait_for, no_wait, json_out)
     help="Write json results out to a named file path",
     type=click.File("w", encoding="utf-8"),
 )
+@click.option(
+    "-p",
+    "--patch-series",
+    type=file_or_url,
+    default=None,
+    help=(
+        "Patches to apply before building the kernel. Accepts patch "
+        "series that applies directly with 'git am' or "
+        "'git quiltimport' i.e., a mbox file or directory or gzipped "
+        "tarball (.tar.gz)"
+    ),
+)
 @click.argument("config")
 def plan(
     name,
